# Changelog

## 1.0.0 - 2023-07-01
- Initial release

## 1.0.1 - 2023-07-01
- edit README.md

## 1.0.2 - 2023-07-01
- edit README.md

## 1.0.3 - 2023-07-01
- fix clearing messages from redis

## 1.0.4 - 2023-10-13
- update aiogram version
- change json to pickle, now supports more types of data

## 1.0.5 - 2023-10-19
- correcting README
- update settings to TypedDict
- add sending raw aiogram functions
- add possibility to send message from django


## 1.0.6 - 2023-10-21
- rm parse_mode by default
- add the ability to flexibly configure default kwargs for different aiogram functions
- edit min aiogram version
